#
# spec file for package libwebp
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libwebp
Version:        0.5.0
Release:        150000.3.11.1
Summary:        Library and tools for the WebP graphics format
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            https://developers.google.com/speed/webp/

#Git-Clone:	http://git.chromium.org/webm/libwebp.git
Source:         http://downloads.webmproject.org/releases/webp/%name-%version.tar.gz
Source2:        http://downloads.webmproject.org/releases/webp/%name-%version.tar.gz.asc
Source3:        %name.keyring
Source4:        baselibs.conf
# PATCH-FIX-UPSTREAM libwebp-CVE-2020-36328.patch bsc#1185688 mgorse@suse.com -- fix invalid check for buffer size.
Patch0:         libwebp-CVE-2020-36328.patch
# PATCH-FIX-UPSTREAM libwebp-CVE-2020-36329.patch bsc#1185652 mgorse@suse.com -- fix for thread race heap-use-after-free.
Patch1:         libwebp-CVE-2020-36329.patch
# PATCH-FIX-UPSTREAM libwebp-CVE-2020-36330.patch bsc#1185691 mgorse@suse.com -- fix riff size checks.
Patch2:         libwebp-CVE-2020-36330.patch
# PATCH-FIX-UPSTREAM libwebp-CVE-2018-25013.patch bsc#1185654 mgorse@suse.com -- wait for all threads to be done in DecodeRemaining.
Patch3:         libwebp-CVE-2018-25013.patch
# PATCH-FIX-UPSTREAM libwebp-CVE-2020-36331.patch bsc#1185686 mgorse@suse.com -- fix possible overflow when validating chunk size.
Patch4:         libwebp-CVE-2020-36331.patch
# PATCH-FIX-UPSTREAM libwebp-CVE-2018-25010.patch bsc#1185685 mgorse@suse.com -- fix alpha-filtering crash when image is larger than radius.
Patch5:         libwebp-CVE-2018-25010.patch
# PATCH-FIX-UPSTREAM libwebp-CVE-2018-25009.patch bsc#1185673 bsc#1186790 mgorse@suse.com -- fix overflow while reading VP8X chunk.
Patch6:         libwebp-CVE-2018-25009.patch
# PATCH-FIX-UPSTREAM libwebp-CVE-2020-36332.patch bsc#1185674 mgorse@suse.com -- better handling of bogus Huffman codes.
Patch7:         libwebp-CVE-2020-36332.patch
# PATCH-FIX-UPSTREAM libwebp-CVE-2018-25011.patch bsc#1186247 mgorse@suse.com -- fail on multiple image chunks.
Patch8:         libwebp-CVE-2018-25011.patch
# PATCH-FIX-UPSTREAM libwebp-double-free.patch bsc#1210212 CVE-2023-1999 xwang@suse.com -- Avoid a double free
Patch9:         libwebp-double-free.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  freeglut-devel
BuildRequires:  giflib-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  pkg-config

%description
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.

%package tools
Summary:        The WebP command line tools
Group:          Productivity/Archiving/Compression
#O/P added in 12.2
Obsoletes:      webp-tools < %version-%release
Provides:       webp-tools = %version-%release

%description tools
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.

%package -n libwebp6
Summary:        Library for the WebP graphics format
Group:          System/Libraries

%description -n libwebp6
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.

%package -n libwebpdemux2
Summary:        Library for extraction of data and images from WebP container files
Group:          System/Libraries

%description -n libwebpdemux2
The WebP Demux API enables extraction of images and extended format
data from WebP files. This API currently supports reading of XMP/EXIF
metadata, ICC profile and animated images.

%package -n libwebpmux2
Summary:        Library for reading/adding data to WebP container files
Group:          System/Libraries

%description -n libwebpmux2
The WebP Mux API contains methods for adding data to and reading data
from WebP files. This API currently supports XMP/EXIF metadata, ICC
profile and animation.

%package -n libwebpdecoder2
Summary:        Library for decoding WebP graphics format
Group:          System/Libraries

%description -n libwebpdecoder2
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.

%package -n libwebpextras0
Summary:        Library for decoding WebP graphics format
Group:          System/Libraries

%description -n libwebpextras0
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently. This package contains shared libraries for less
common imports - WebPImportGray/WebPImportRGB565/WebPImportRGB4444.

%package devel
Summary:        Development files for libwebp, a library for the WebP format
Group:          Development/Libraries/C and C++
Requires:       libwebp6 = %version
Requires:       libwebpdemux2 = %version
Requires:       libwebpmux2 = %version
Requires:       libwebpdecoder2 = %version
Requires:       libwebpextras0 = %version

%description devel
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1

%build
%configure --disable-static \
	--enable-libwebpmux --enable-libwebpdemux \
	--enable-libwebpdecoder --enable-libwebpextras
make %{?_smp_mflags} V=1

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n libwebp6 -p /sbin/ldconfig
%postun -n libwebp6 -p /sbin/ldconfig
%post   -n libwebpdemux2 -p /sbin/ldconfig
%postun -n libwebpdemux2 -p /sbin/ldconfig
%post   -n libwebpmux2 -p /sbin/ldconfig
%postun -n libwebpmux2 -p /sbin/ldconfig
%post   -n libwebpdecoder2 -p /sbin/ldconfig
%postun -n libwebpdecoder2 -p /sbin/ldconfig
%post   -n libwebpextras0 -p /sbin/ldconfig
%postun -n libwebpextras0 -p /sbin/ldconfig

%files -n libwebp-tools
%defattr(-,root,root)
%_bindir/*
%_mandir/man*/*

%files -n libwebp6
%defattr(-,root,root)
%_libdir/libwebp.so.6*

%files -n libwebpdemux2
%defattr(-,root,root)
%_libdir/libwebpdemux.so.2*

%files -n libwebpmux2
%defattr(-,root,root)
%_libdir/libwebpmux.so.2*

%files -n libwebpdecoder2
%defattr(-,root,root)
%_libdir/libwebpdecoder.so.2*

%files -n libwebpextras0
%defattr(-,root,root)
%_libdir/libwebpextras.so.0*

%files devel
%defattr(-,root,root)
%_libdir/libwebp*.so
%_includedir/webp/
%_libdir/pkgconfig/libwebp*.pc

%changelog
* Tue May 30 2023 xiaoguang.wang@suse.com
- Add libwebp-double-free.patch: Avoid a double free, upstream
  commit a486d800 (bsc#1210212 CVE-2023-1999).
* Thu May 27 2021 mgorse@suse.com
- Add libwebp-CVE-2018-25011.patch: fail on
  multiple image chunks (bsc#1186247 CVE-2018-25011).
* Thu May 13 2021 mgorse@suse.com
- Add libwebp-CVE-2020-36328.patch: fix invalid check for buffer
  size (bsc#1185688 CVE-2020-36328).
- Add libwebp-CVE-2020-36329.patch: fix for thread race heap use
  after free (bsc#1185652 CVE-2020-36329).
- Add libwebp-CVE-2020-36330.patch: fix riff size checks
  (bsc#1185691 CVE-2020-36330).
- Add libwebp-CVE-2018-25013.patch: wait for all threads to be
  done in DecodeRemaining (bsc#1185654 bsc#1186250 CVE-2018-25013
  CVE-2018-25014).
- Add libwebp-CVE-2020-36331.patch: fix possible overflow when
  validating chunk size (bsc#1185686 CVE-2020-36331).
- Add libwebp-CVE-2018-25010.patch: fix alpha-filtering crash when
  image is larger than radius (bsc#1185685 CVE-2018-25010).
- Add libwebp-CVE-2018-25009.patch: fix overflow while reading
  VP8X chunk (bsc#1185673 bsc#1185690 CVE-2018-25009
    CVE-2018-25012).
- Add libwebp-CVE-2020-36332.patch: better handling of bogus
  Huffman code (bsc#1185674 CVE-2020-36332).
* Fri Feb 12 2016 mpluskal@suse.com
- Update baselibs.conf
* Thu Feb 11 2016 mpluskal@suse.com
- Update to 0.5.0
  * miscellaneous bug & build fixes (issues #234, #258, #274, #275,
    [#278])
  * encoder & decoder speed-ups on x86/ARM/MIPS for lossy &
    lossless
    + note! YUV->RGB conversion was sped-up, but the results will
    be slightly different from previous releases
  * various lossless encoder improvements
  * gif2webp improvements, -min_size option added
  * tools fully support input from stdin and output to stdout (issue
    [#168])
  * New WebPAnimEncoder API for creating animations
  * New WebPAnimDecoder API for decoding animations
  * other API changes:
    + libwebp:
    WebPPictureSmartARGBToYUVA() (-pre 4 in cwebp)
    WebPConfig::exact (-exact in cwebp; -alpha_cleanup is now the
    default)
    WebPConfig::near_lossless (-near_lossless in cwebp)
    WebPFree() (free'ing webp allocated memory in other
    languages)
    WebPConfigLosslessPreset()
    WebPMemoryWriterClear()
    + libwebpdemux: removed experimental fragment related fields
    and functions
    + libwebpmux: WebPMuxSetCanvasSize()
  * new libwebpextras library with some uncommon import functions:
    WebPImportGray/WebPImportRGB565/WebPImportRGB4444
- Make building more verbose
* Tue Dec  8 2015 p.drouand@gmail.com
- Update to version 0.4.4
  * rescaling out-of-bounds read fix (issue #254)
  * various build fixes and improvements (issues #253, #259, #262, #267, #268)
  * container documentation update
  * gif2webp transparency fix (issue #245)
- Add freeglut-devel build requires
* Mon Jun 29 2015 jengelh@inai.de
- Add libwebp-devel to baselibs.conf [bnc#936417]
* Sat Jun 13 2015 dmueller@suse.com
- remove aarch64-disable-neon.diff: compiler was fixed, neon
  can be compiled now
* Sun Mar 29 2015 jengelh@inai.de
- Update to new upstream release 0.4.3
  * lossless decode fix and a multi-threading fix
  * documentation / vwebp updates for animation
* Wed Oct 29 2014 dimstar@opensuse.org
- Update baselibs.conf: make it match the currently build library
  packages.
* Tue Oct 28 2014 dmueller@suse.com
- update to 0.4.2:
  This is a binary compatible release.
  * Android / gcc build fixes
  * (Windows) fix reading from stdin and writing to stdout
  * gif2webp: miscellaneous fixes
  * fix 'alpha-leak' with lossy compression (issue #220)
  * the lossless bitstream spec has been amended to reflect the current code
- add aarch64-disable-neon.diff: work around compile failure with
  neon on aarch64.
- add libwebpdecoder1 subpackage
* Mon Aug 11 2014 jengelh@inai.de
- Update to new upstream release 0.4.1
  * AArch64 (arm64) & MIPS support/optimizations
  * NEON assembly additions: ~25%% faster lossy decode/encode (-m 4);
  ~10%% faster lossless decode;~5-10%% faster lossless encode (-m 3/4)
  * dwebp/vwebp can read from stdin
  * cwebp/gif2webp can write to stdout
  * cwebp can read webp files; useful if storing sources as webp
  lossless
* Thu Jan  9 2014 jengelh@inai.de
- Update to new upstream release 0.4.0
  * improved gif2webp tool
  * numerous fixes, compression improvement and speed-up
  * dither option added to decoder (dwebp -dither 50 ...)
  * improved multi-threaded modes (-mt option)
  * improved filtering strength determination
  * BMP and TIFF format output added to 'dwebp'
  * Significant memory reduction for decoding lossy images with alpha.
  * Intertwined decoding of RGB and alpha for a shorter
  time-to-first-decoded-pixel.
  * WebPIterator has a new member 'has_alpha' denoting whether the
  frame contains transparency.
  * Container spec amended with new 'blending method' for animation.
* Wed Jun 26 2013 jengelh@inai.de
- Update to new upstream release 0.3.1
  * Add incremental decoding support for images containing
  ALPH and ICCP chunks.
- Enable libwebpmux, libwebpdemux
* Tue Apr 16 2013 jengelh@inai.de
- Update to new upstream release 0.3.0
  * WebPINewRGB/WebPINewYUVA accept being passed a NULL output buffer
  and will perform auto-allocation.
  * Default filter option is now "-strong -f 60"
  * Encoding speed-up for lossy methods 3 to 6
  * Alpha encoding can be done in parallel to lossy using
  `cwebp -mt ...`
  * Color profile, metadata (XMP/EXIF) and animation support in the
  container was finalized.
  * Various NEON assembly additions
- Tool updates / additions:
  * gif2webp added
  * vwebp given color profile & animation support
  * cwebp can preserve color profile / metadata with "-metadata"
* Sun Dec  9 2012 mailaender@opensuse.org
- Update to version 0.2.1
  * libwebp: validate chunk size in ParseOptionalChunks
  * cwebp (windows): fix alpha image import on XP
  * autoconf/libwebp: enable dll builds for mingw
  * [cd]webp: always output windows errors
  * fix double to float conversion warning
  * cwebp: fix jpg encodes on XP
  * VP8LAllocateHistogramSet: fix overflow in size calculation
  * GetHistoBits: fix integer overflow
  * EncodeImageInternal: fix uninitialized free
  * fix the -g/O3 discrepancy for 32bit compile
  * fix the BITS=8 case
  * Make *InitSSE2() functions be empty on non-SSE2 platform
  * make *InitSSE2() functions be empty on non-SSE2 platform
  * make VP8DspInitNEON() public
* Fri Aug 31 2012 dimstar@opensuse.org
- Update to version 0.2.0:
  * Add support for ARGB -> YUVA conversion for lossless decoder
  * Add stats for lossless and alpha encoding
  * Security related hardening: allocation and size checks
  * Add PAM output support to dwebp
  * Alpha channel encode/decode support
  * Lossless encoder/decoder
  * Add TIFF input support to cwebp
  * Incompatible changes:
  - The encode ABI has been modified to support alpha encoding
  - Deprecated function WebPINew() has been removed
  - Decode function signatures have changed to consistently use
    size_t over int/uint32_t
  - decode_vp8.h is no longer installed system-wide
  - cwebp will encode the alpha channel if present.
  * Add libtiff-devel BuildRequires for the new tiff input support.
  * Rename libwebp2 subpackage to libwebp4 (by changing lname
  defines), following upstreams soname bump (incl. baselibs.conf).
  * No reason to run autogen
* Mon Jan 30 2012 jengelh@medozas.de
- Rename webp-tools to libwebp-tools to follow scheme of other
  lib*-tools packages.
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Oct 31 2011 pgajdos@suse.com
- update to 0.1.3:
  * Advanced decoding APIs.
  * On-the-fly cropping and rescaling of images.
  * SSE2 instructions for decoding performance optimizations on x86 based platforms.
  * Support Multi-threaded decoding.
  * 40%% improvement in Decoding performance.
  * Add support for RGB565, RGBA4444 & ARGB image colorspace.
  * Better handling of large picture encoding.
* Fri Sep 16 2011 coolo@suse.com
- add baselibs.conf and use original tar
* Sat Aug  6 2011 jengelh@medozas.de
- Rename subpackage libwebp-tools to webp-tools to get out of
  rpmlint's pedant observation that it does not contain libraries.
